@@ -19,7 +19,9 @@ rm -f usr/share/icons/icon-theme.cache
 
 # Update hicolor theme cache:
 if [ -d usr/share/icons/hicolor ]; then
-  if [ -x /usr/bin/gtk-update-icon-cache ]; then
-    chroot . /usr/bin/gtk-update-icon-cache -f -t usr/share/icons/hicolor 1> /dev/null 2> /dev/null
+  if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then # ONLY run this if there's already a cache!!!
+    if [ -x /usr/bin/gtk-update-icon-cache ]; then
+      chroot . /usr/bin/gtk-update-icon-cache -f -t usr/share/icons/hicolor 1> /dev/null 2> /dev/null
+    fi
   fi
 fi
